Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(377)

Unified Diff: apps/app_shim/app_shim_host_manager_mac.h

Issue 305973002: Rename IPC::ChannelFactory to ChannelHandleAcceptor. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 6 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « apps/app_shim/app_shim_host_manager_browsertest_mac.mm ('k') | apps/app_shim/app_shim_host_manager_mac.mm » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: apps/app_shim/app_shim_host_manager_mac.h
diff --git a/apps/app_shim/app_shim_host_manager_mac.h b/apps/app_shim/app_shim_host_manager_mac.h
index 0e3a9d28338cf4bb6a63c0704e6a2448d4771400..037c4f24b1cd9f052a7dad6b7b04a00bd2f3d48c 100644
--- a/apps/app_shim/app_shim_host_manager_mac.h
+++ b/apps/app_shim/app_shim_host_manager_mac.h
@@ -6,9 +6,9 @@
#define APPS_APP_SHIM_APP_SHIM_HOST_MANAGER_MAC_H_
#include "apps/app_shim/extension_app_shim_handler_mac.h"
+#include "apps/app_shim/unix_domain_socket_acceptor.h"
#include "base/memory/ref_counted.h"
#include "content/public/browser/browser_thread.h"
-#include "ipc/ipc_channel_factory.h"
namespace base {
class FilePath;
@@ -19,11 +19,11 @@ class AppShimHostManagerTestApi;
}
// The AppShimHostManager receives connections from app shims on a UNIX
-// socket (|factory_|) and creates a helper object to manage the connection.
-class AppShimHostManager
- : public IPC::ChannelFactory::Delegate,
- public base::RefCountedThreadSafe<
- AppShimHostManager, content::BrowserThread::DeleteOnUIThread> {
+// socket (|acceptor_|) and creates a helper object to manage the connection.
+class AppShimHostManager : public apps::UnixDomainSocketAcceptor::Delegate,
+ public base::RefCountedThreadSafe<
+ AppShimHostManager,
+ content::BrowserThread::DeleteOnUIThread> {
public:
AppShimHostManager();
@@ -44,11 +44,11 @@ class AppShimHostManager
friend class test::AppShimHostManagerTestApi;
virtual ~AppShimHostManager();
- // IPC::ChannelFactory::Delegate implementation.
+ // UnixDomainSocketAcceptor::Delegate implementation.
virtual void OnClientConnected(const IPC::ChannelHandle& handle) OVERRIDE;
virtual void OnListenError() OVERRIDE;
- // The |factory_| must be created on a thread which allows blocking I/O, so
+ // The |acceptor_| must be created on a thread which allows blocking I/O, so
// part of the initialization of this class must be carried out on the file
// thread.
void InitOnFileThread();
@@ -63,7 +63,7 @@ class AppShimHostManager
base::FilePath directory_in_tmp_;
- scoped_ptr<IPC::ChannelFactory> factory_;
+ scoped_ptr<apps::UnixDomainSocketAcceptor> acceptor_;
apps::ExtensionAppShimHandler extension_app_shim_handler_;
« no previous file with comments | « apps/app_shim/app_shim_host_manager_browsertest_mac.mm ('k') | apps/app_shim/app_shim_host_manager_mac.mm » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698